@@ -10,15 +10,14 @@ use crate::{
     command::{escaped::EscapedCommand, external::ExternalCommand, normal::NormalCommand},
     nodes::{Literal, MaybeRanged},
     value::*,
-    ASTKind, ASTNode, Value,
+    ASTKind, ASTNode,
 };
-use num::BigUint;
 use std::ops::Range;
 
 #[derive(Clone, Debug, Default, Eq, PartialEq)]
 pub struct CommandOptions {
-    args: SparseArray,
-    kvs: OrderedMap,
+    pub args: SparseArray,
+    pub kvs: OrderedMap,
 }
 
 #[derive(Clone, Default, Eq, PartialEq)]
