@@ -34,6 +34,12 @@ pub enum Value {
     Object(Box<OrderedMap>),
 }
 
+impl Default for Value {
+    fn default() -> Self {
+        Self::Null
+    }
+}
+
 impl Value {
     /// convert a integer to value
     pub fn integer(value: impl Into<BigInt>) -> Self {
